/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) 2009 - DIGITEO
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

#ifndef __GETCOMMANDLINE_H__
#define __GETCOMMANDLINE_H__
/*--------------------------------------------------------------------------*/

#include "dynlib_shell.h"

/**
* getConsoleInputLine function
* @return characters 
*/
SHELL_IMPEXP char *getConsoleInputLine(void);

/*--------------------------------------------------------------------------*/
#endif /* __GETCOMMANDLINE_H__ */

